%define rname	RubyGems
%define	oname	rubygems

%define rubygems_dir %{_datadir}/rubygems
%define gem_dir %{_datadir}/ruby/gems
%define gem_extdir %{_exec_prefix}/lib{,64}/gems

%define bootstrap 0
%define subrel 1

Summary:	Ruby package manager
Name:		ruby-%{rname}
Version:	2.1.11
Release:	%mkrel 3
License:	GPLv2+
Group:		Development/Ruby
URL:		http://docs.rubygems.org/
Source0:	http://production.cf.rubygems.org/rubygems/%{oname}-%{version}.tgz
# Sources from the works by Vít Ondruch <vondruch@redhat.com>
Source100:	operating_system.rb
# Add support for installing binary extensions according to FHS.
# https://github.com/rubygems/rubygems/issues/210
Patch109: rubygems-2.1.x-binary-extensions.patch

Patch110: CVE-2015-3900.patch
Patch111: CVE-2015-4020.patch
# Fixes compatibility with recent openssl in a test
Patch112: rubygem-2.4.8-Increase-DH-key-size-fixes-1289.patch
# Allow running tests with minitest5
Patch113: rubygems-2.1.11-minitest5.patch

BuildArch:	noarch
BuildRequires:	ruby
BuildRequires:	locales-en
# If !%bootstrap installed rubygem may be boostrap and not require it
%if !%bootstrap
BuildRequires:	rubygem(rdoc)
%endif
# For tests
BuildRequires:	ruby-rake
BuildRequires:	ruby-minitest
Requires:	locales
Requires:	ruby
Requires:	rootcerts
%if !%bootstrap
Requires:	rubygem(rdoc)
%endif
Provides:	%{oname} = %{version}
Provides:	ruby(rubygems) = %{version}-%{release}

%description
RubyGems is the Ruby standard for publishing and managing third party
libraries.

%prep
%setup -q -n rubygems-%{version}
%apply_patches

%install
LANG=en_US.UTF-8 GEM_HOME=%{buildroot}/%{gem_dir} \
    ruby setup.rb --prefix=/\
%if !%bootstrap
        --rdoc --ri \
%else
        --no-document --no-rdoc --no-ri \
%endif
        --destdir=%{buildroot}/%{rubygems_dir}/

mkdir -p %{buildroot}/%{_bindir}
mv %{buildroot}/%{rubygems_dir}/bin/gem %{buildroot}/%{_bindir}/gem
rm -rf %{buildroot}/%{rubygems_dir}/bin

mv %{buildroot}/%{rubygems_dir}/lib/* %{buildroot}/%{rubygems_dir}/.
# No longer needed
rmdir %{buildroot}%{rubygems_dir}/lib

# Install custom operating_system.rb.
mkdir -p %{buildroot}%{rubygems_dir}/rubygems/defaults
install -cpm 0644 %{SOURCE100} %{buildroot}%{rubygems_dir}/rubygems/defaults/

# Kill bundled cert.pem
mkdir -p %{buildroot}%{rubygems_dir}/rubygems/ssl_certs/
ln -sf %{_sysconfdir}/pki/tls/cert.pem \
	%{buildroot}%{rubygems_dir}/rubygems/ssl_certs/ca-bundle.pem

# Create gem folders.
mkdir -p %{buildroot}%{gem_dir}/{cache,gems,specifications,doc}
mkdir -p %{buildroot}%{gem_extdir}

# Create macros.rubygems file for rubygems-devel
mkdir -p %{buildroot}%{_sysconfdir}/rpm/macros.d

cat >> %{buildroot}%{_sysconfdir}/rpm/macros.d/rubygems.macros << \EOF
# The RubyGems root folder.
%%gem_dir %{gem_dir}

# Common gem locations and files.
%%gem_instdir %%{gem_dir}/gems/%%{gem_name}-%%{version}
%%gem_extdir_mri %%{_libdir}/gems/ruby/%%{gem_name}-%%{version}
%%gem_libdir %%{gem_instdir}/lib
%%gem_cache %%{gem_dir}/cache/%%{gem_name}-%%{version}.gem
%%gem_spec %%{gem_dir}/specifications/%%{gem_name}-%%{version}.gemspec
%%gem_docdir %%{gem_dir}/doc/%%{gem_name}-%%{version}
EOF

%check
# Many tests are broken but this one, testing the CVE fixes, works
ruby -Ilib test/rubygems/test_gem_remote_fetcher.rb

%files
%doc README* 
%doc History.txt
%doc MIT.txt LICENSE.txt
%dir %{gem_dir}
%dir %{gem_dir}/cache
%dir %{gem_dir}/gems
%dir %{gem_dir}/specifications
%doc %{gem_dir}/doc
%{_bindir}/gem

%dir %{rubygems_dir}/
%{rubygems_dir}/rubygems/
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb
%{rubygems_dir}/gauntlet_rubygems.rb

%dir %{_exec_prefix}/lib/gems
%dir %{_exec_prefix}/lib64/gems

%{_sysconfdir}/rpm/macros.d/rubygems.macros


%changelog
* Thu Sep 03 2015 luigiwalser <luigiwalser> 2.1.11-3.1.mga4
+ Revision: 872455
- Add patches for CVE-2015-3900 and CVE-2015-4020, and enable test for those

* Sat Dec 28 2013 pterjan <pterjan> 2.1.11-3.mga4
+ Revision: 562414
- Update operating_system.rb for new extensions path

* Fri Dec 27 2013 pterjan <pterjan> 2.1.11-2.mga4
+ Revision: 560983
- Fix use of wrong macro now that they are different
- Move rubygems out of gems dir as this brakes bundler
- Make gem_extdir_mri mri specific

* Tue Dec 17 2013 pterjan <pterjan> 2.1.11-1.mga4
+ Revision: 558310
- Update to 2.1.11, sync more with Fedora and try fixing binary extensions packaging

* Sat Nov 23 2013 fwang <fwang> 2.0.10-3.mga4
+ Revision: 552434
- requires rootcerts for cert.pem

* Mon Oct 21 2013 umeabot <umeabot> 2.0.10-2.mga4
+ Revision: 539404
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 fwang <fwang> 2.0.10-1.mga4
+ Revision: 492123
- new version 2.0.10

* Tue Sep 24 2013 fwang <fwang> 2.0.8-1.mga4
+ Revision: 484661
- new version 2.0.8

* Fri Sep 20 2013 pterjan <pterjan> 2.0.7-6.mga4
+ Revision: 481763
- Fix switch out of bootstrap
- Disable bootstrap

* Fri Sep 20 2013 pterjan <pterjan> 2.0.7-5.mga4
+ Revision: 481738
- Drop _requires_exceptions

* Fri Sep 20 2013 pterjan <pterjan> 2.0.7-4.mga4
+ Revision: 481714
- Disable ruby-abi dependency for ruby 2 transition

* Wed Aug 21 2013 fwang <fwang> 2.0.7-3.mga4
+ Revision: 468841
- build bootstrap for ruby2.0

* Mon Aug 19 2013 fwang <fwang> 2.0.7-2.mga4
+ Revision: 467696
- build docs

* Mon Aug 19 2013 fwang <fwang> 2.0.7-1.mga4
+ Revision: 467691
- rediff patch
- new version 2.0.7

* Sat Aug 17 2013 fwang <fwang> 2.0.6-2.mga4
+ Revision: 467059
- do not build any docs
- disable rdoc as it cannot be found
- we are using different prefix than fedora
- push to updates_testing

* Thu Aug 15 2013 fwang <fwang> 2.0.6-1.mga4
+ Revision: 466676
- new version 2.0.6

* Sun Jul 21 2013 fwang <fwang> 2.0.5-1.mga4
+ Revision: 456758
- new version 2.0.5

* Sun Jun 02 2013 pterjan <pterjan> 2.0.3-1.mga4
+ Revision: 435464
- BuildRequires locales-en, to be able to really force to an UTF-8 locale
- Update to 2.0.3

* Sun Jun 02 2013 pterjan <pterjan> 1.8.24-10.mga4
+ Revision: 434725
- Fix operating_system.rb so that common_path work when paths have different depth

* Fri Feb 08 2013 umeabot <umeabot> 1.8.24-9.mga3
+ Revision: 395701
- Rebuild for CVE-2013-0256

* Mon Jan 14 2013 umeabot <umeabot> 1.8.24-8.mga3
+ Revision: 380608
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 02 2012 fwang <fwang> 1.8.24-7.mga3
+ Revision: 312398
- add locales for building downstream packages

* Thu Nov 01 2012 fwang <fwang> 1.8.24-6.mga3
+ Revision: 312067
- add requires on rdoc so that we build rdoc by default for gems

* Wed Oct 31 2012 fwang <fwang> 1.8.24-5.mga3
+ Revision: 311715
- sync with fedora patches

* Thu Sep 13 2012 fwang <fwang> 1:1.8.24-4.mga3
+ Revision: 293439
+ rebuild (emptylog)

* Sun Jun 10 2012 shlomif <shlomif> 1.8.24-3.mga3
+ Revision: 259456
- New version - 1.8.24

* Mon Oct 03 2011 lebedov <lebedov> 1.7.2-3.mga2
+ Revision: 151368
- Update to 1.7.2.

* Wed Feb 16 2011 shikamaru <shikamaru> 1.5.2-1.mga1
+ Revision: 52189
- new version 1.5.2
- new version 1.5.1
- new version 1.5.0

* Mon Jan 17 2011 shikamaru <shikamaru> 1.3.7-1.mga1
+ Revision: 20990
- Spec cleaning
- reorder Tags to match the spec file syntax policy
- fix License
- fix URL (more update friendly)
- fix rpmlint warning 'mixed use of space and tabs'
- remove useless ruby require, add ruby(abi) require
- kill definition of %%buildroot
- use curly braces around custom variables (to match policy)
- use /usr/bin/env in scripts
- imported package ruby-RubyGems

